@@ -11,69 +11,35 @@ use Spp::Builtin;
 use Spp::Core;
 
 sub opt_spp_ast {
-   my $ast   = shift;
-   my $atoms = [];
-   if (is_atom($ast)) {
-      my ($name, $spec) = @{$ast};
-      if ($name eq 'Spec') {
-         return [opt_spp_spec($spec)];
-      }
-   }
-   for my $atom (@{$ast}) {
-      my ($name, $spec) = @{$atom};
-      if ($name eq 'Spec') {
-         push @{$atoms}, opt_spp_spec($spec);
-      }
-   }
-   return $atoms;
+   my $ast = shift;
+   return [ opt_atom($ast) ] if is_atom($ast);
+   return map_opt_atom($ast);
 }
 
-sub opt_spp_spec {
+sub map_opt_atom {
    my $atoms = shift;
-   my $token = $atoms->[0];
-   my $name      = $token->[1];
-   my $rules     = rest($atoms);
-   my $opt_rules = opt_spp_rules($rules);
-   return [$name, $opt_rules];
+   return [ map { opt_atom($_) } @{$atoms} ];
 }
 
-sub opt_spp_rules {
-   my $rules     = shift;
-   my $opt_rules = opt_spp_atoms($rules);
-   if (len($opt_rules) == 1) {
-      return $opt_rules->[0];
-   }
-   return ['Rules', $opt_rules];
-}
-
-sub opt_spp_atoms {
-   my $atoms = shift;
-   my $opt_atoms = [map { opt_spp_atom($_) } @{$atoms}];
-   $opt_atoms = gather_spp_tillnot($opt_atoms);
-   $opt_atoms = gather_spp_look($opt_atoms);
-   $opt_atoms = gather_spp_rept($opt_atoms);
-   return $opt_atoms;
-}
-
-sub opt_spp_atom {
+sub opt_atom {
    my $atom = shift;
    my ($name, $value) = @{$atom};
    given ($name) {
-      when ('Group')   { return opt_spp_group($value) }
-      when ('Branch')  { return opt_spp_branch($value) }
-      when ('Lbranch') { return opt_spp_lbranch($value) }
-      when ('Cclass')  { return opt_spp_cclass($value) }
-      when ('Char')    { return opt_spp_char($value) }
-      when ('Str')     { return opt_spp_str($value) }
-      when ('String')  { return opt_spp_str($value) }
-      when ('Kstr')    { return opt_spp_kstr($value) }
-      when ('Point')   { return opt_spp_point($value) }
-      when ('Chclass') { return opt_spp_chclass($value) }
-      when ('Look')    { return opt_spp_look($value) }
-      when ('Token')   { return opt_spp_token($value) }
-      when ('Expr')    { return opt_spp_expr($value) }
-      when ('Sym')     { return opt_spp_sym($value) }
-      when ('Array')   { return opt_spp_array($value) }
+      when ('Spec')    { return opt_spec($value)  }
+      when ('Group')   { return opt_group($value) }
+      when ('Branch')  { return opt_branch($value) }
+      when ('Cclass')  { return opt_cclass($value) }
+      when ('Char')    { return opt_char($value) }
+      when ('Str')     { return opt_str($value) }
+      when ('String')  { return opt_str($value) }
+      when ('Kstr')    { return opt_kstr($value) }
+      when ('Point')   { return opt_point($value) }
+      when ('Chclass') { return opt_chclass($value) }
+      when ('Look')    { return opt_look($value) }
+      when ('Token')   { return opt_token($value) }
+      when ('Expr')    { return opt_expr($value) }
+      when ('Sym')     { return opt_sym($value) }
+      when ('Array')   { return opt_array($value) }
       when ('Assert')  { return $atom }
       when ('Any')     { return $atom }
       when ('Till')    { return $atom }
@@ -83,52 +49,67 @@ sub opt_spp_atom {
    }
 }
 
-sub opt_spp_point {
+sub opt_spec {
+   my $atoms = shift;
+   my $token = $atoms->[0];
+   my $name  = $token->[1];
+   my $rules = rest($atoms);
+   return [$name, opt_rules($rules)];
+}
+
+sub opt_rules {
+   my $rules     = shift;
+   my $opt_rules = opt_atoms($rules);
+   return $opt_rules->[0] if len($opt_rules) == 1;
+   return ['Rules', $opt_rules];
+}
+
+sub opt_atoms {
+   my $atoms = shift;
+   my $opt_atoms = map_opt_atom($atoms);
+   $opt_atoms = gather_tillnot($opt_atoms);
+   $opt_atoms = gather_look($opt_atoms);
+   $opt_atoms = gather_rept($opt_atoms);
+   return $opt_atoms;
+}
+
+sub opt_point {
    my $point = shift;
    return ['Char', chr(hex($point))];
 }
 
-sub opt_spp_group {
+sub opt_group {
    my $atoms     = shift;
-   my $opt_atoms = opt_spp_atoms($atoms);
-   if (len($opt_atoms) == 1) {
-      return $opt_atoms->[0];
-   }
+   my $opt_atoms = opt_atoms($atoms);
+   return $opt_atoms->[0] if len($opt_atoms) == 1;
    return ['Group', $opt_atoms];
 }
 
-sub opt_spp_branch {
+sub opt_branch {
    my $atoms     = shift;
-   my $opt_atoms = opt_spp_atoms($atoms);
+   my $opt_atoms = opt_atoms($atoms);
    return $opt_atoms->[0] if len($opt_atoms) == 1;
    return ['Branch', $opt_atoms];
 }
 
-sub opt_spp_lbranch {
-   my $atoms     = shift;
-   my $opt_atoms = opt_spp_atoms($atoms);
-   return $opt_atoms->[0] if len($opt_atoms) == 1;
-   return ['Lbranch', $opt_atoms];
-}
-
-sub opt_spp_kstr {
+sub opt_kstr {
    my $kstr = shift;
    my $str  = substr($kstr, 1);
    return ['Char', $str] if len($str) == 1;
    return ['Str', $str];
 }
 
-sub opt_spp_cclass {
+sub opt_cclass {
    my $cclass = shift;
    return ['Cclass', substr($cclass, -1)];
 }
 
-sub opt_spp_char {
+sub opt_char {
    my $char = shift;
-   return ['Char', opt_spp_escape_char($char)];
+   return ['Char', opt_escape_char($char)];
 }
 
-sub opt_spp_escape_char {
+sub opt_escape_char {
    my $str  = shift;
    my $char = substr($str, -1);
    given ($char) {
@@ -141,7 +122,7 @@ sub opt_spp_escape_char {
    }
 }
 
-sub opt_spp_chclass {
+sub opt_chclass {
    my $nodes = shift;
    my $atoms = [];
    my $flip  = 0;
@@ -149,7 +130,7 @@ sub opt_spp_chclass {
       my ($name, $value) = @{$node};
       if ($name eq 'Flip') { $flip = 1; }
       else {
-         my $atom = opt_spp_catom($name, $value);
+         my $atom = opt_catom($name, $value);
          push @{$atoms}, $atom;
       }
    }
@@ -157,30 +138,30 @@ sub opt_spp_chclass {
    return ['Nchclass', $atoms];
 }
 
-sub opt_spp_catom {
+sub opt_catom {
    my ($name, $value) = @_;
    given ($name) {
-      when ('Cclass') { return opt_spp_cclass($value) }
-      when ('Range')  { return opt_spp_range($value) }
-      when ('Char')   { return opt_spp_char($value) }
+      when ('Cclass') { return opt_cclass($value) }
+      when ('Range')  { return opt_range($value) }
+      when ('Char')   { return opt_char($value) }
       when ('Cchar')  { return ['Char', $value] }
       default         { die("unknown cclass atom $name") }
    }
 }
 
-sub opt_spp_range {
+sub opt_range {
    my $range = shift;
    return ['Range', [split('-', $range)]];
 }
 
-sub opt_spp_look {
+sub opt_look {
    my $atoms = shift;
    my $rept  = $atoms->[0][1];
    return ['_rept', $rept] if len($atoms) == 1;
    return ['_look', $rept];
 }
 
-sub gather_spp_tillnot {
+sub gather_tillnot {
    my $atoms     = shift;
    my @opt_atoms = ();
    my $flag      = 0;
@@ -209,7 +190,7 @@ sub gather_spp_tillnot {
    return [@opt_atoms];
 }
 
-sub gather_spp_look {
+sub gather_look {
    my $atoms     = shift;
    my @opt_atoms = ();
    my $flag      = 0;
@@ -217,14 +198,14 @@ sub gather_spp_look {
    my $look      = '';
    for my $atom (@{$atoms}) {
       if ($flag == 0) {
-         if (is_atom_look($atom)) {
+         if (is_atom_name($atom, '_look')) {
             die("Look token less prefix atom: $atom");
          } else {
             $cache = $atom;
             $flag  = 1;
          }
       } elsif ($flag == 1) {
-         if (is_atom_look($atom)) {
+         if (is_atom_name($atom, '_look')) {
             $look = $atom->[1];
             $flag = 2;
          } else {
@@ -232,7 +213,7 @@ sub gather_spp_look {
             $cache = $atom;
          }
       } else {
-         if (!is_atom_look($atom)) {
+         if (!is_atom_name($atom, '_look')) {
             $cache = ['Look', [$look, $cache, $atom]];
             push @opt_atoms, $cache;
             $flag = 0;
@@ -246,14 +227,14 @@ sub gather_spp_look {
    return [@opt_atoms];
 }
 
-sub gather_spp_rept {
+sub gather_rept {
    my $atoms = shift;
    my @opt_atoms;
    my $flag  = 0;
    my $cache = '';
    for my $atom (@{$atoms}) {
       if ($flag == 0) {
-         if (is_atom_rept($atom)) {
+         if (is_atom_name($atom, '_rept')) {
             die("rept without token");
          }
          else {
@@ -262,7 +243,7 @@ sub gather_spp_rept {
          }
       }
       else {
-         if (is_atom_rept($atom)) {
+         if (is_atom_name($atom, '_rept')) {
             my $rept = $atom->[1];
             push @opt_atoms, ['Rept', [$rept, $cache]];
             $flag = 0;
@@ -277,7 +258,7 @@ sub gather_spp_rept {
    return [@opt_atoms];
 }
 
-sub opt_spp_token {
+sub opt_token {
    my $name = shift;
    my $char = first($name);
    return ['Ntoken', $name] if is_char_upper($char);
@@ -286,9 +267,9 @@ sub opt_spp_token {
    die "Unknown token: <$name> to Opt";
 }
 
-sub opt_spp_expr {
+sub opt_expr {
    my $atoms     = shift;
-   my $opt_atoms = [map { opt_spp_atom($_) } @{$atoms}];
+   my $opt_atoms = map_opt_atom($atoms);
    my $action    = $opt_atoms->[0];
    if (is_atom_sym($action)) {
       $opt_atoms->[0] = $action->[1];
@@ -297,21 +278,21 @@ sub opt_spp_expr {
    die "Expr not action: {$action->[1]}";
 }
 
-sub opt_spp_sym {
+sub opt_sym {
    my $name = shift;
    return ['false'] if $name eq 'false';
    return ['true']  if $name eq 'true';
    return ['Sym', $name];
 }
 
-sub opt_spp_array {
+sub opt_array {
    my $atoms = shift;
    return ['Array', []] if is_str($atoms);
-   my @opt_atoms = map { opt_spp_atom($_) } @{$atoms};
-   return ['Array', [@opt_atoms]];
+   my $opt_atoms = map_opt_atom($atoms);
+   return ['Array', $opt_atoms];
 }
 
-sub opt_spp_str {
+sub opt_str {
    my $atoms     = shift;
    my $opt_atoms = [];
    for my $atom (@{$atoms}) {
@@ -320,7 +301,7 @@ sub opt_spp_str {
          when ('Schars') { push @{$opt_atoms}, $value }
          when ('Chars')  { push @{$opt_atoms}, $value }
          when ('Char') {
-            my $char = opt_spp_escape_char($value);
+            my $char = opt_escape_char($value);
             push @{$opt_atoms}, $char;
          }
          default { die("unknown string atom: <$name>") }
